@@ -16,7 +16,7 @@
 #' control variables in the model (i.e., \code{~ gender}).
 #'
 #' @param prior_sd Numeric. The scale of the prior distribution (centered at zero),
-#'                 in reference to a beta distribtuion (defaults to 0.25).
+#'                 in reference to a beta distribtuion (defaults to sqrt(1/12) ensuring a flat prior).
 #'
 #' @param type Character string. Which type of data for \code{Y} ? The options include \code{continuous},
 #' \code{binary}, \code{ordinal}, or \code{mixed}. Note that mixed can be used for data with only
@@ -246,7 +246,7 @@
 #' # indecrease prior SD
 #' test <- ggm_compare_confirm(Ymale,
 #'                             Yfemale,
-#'                             prior_sd = 0.5,
+#'                             prior_sd = 0.28,
 #'                             hypothesis = hypothesis,
 #'                             iter = 250,
 #'                             progress = FALSE)
@@ -336,11 +336,11 @@ ggm_compare_confirm <- function(...,
                                 formula = NULL,
                                 type = "continuous",
                                 mixed_type = NULL,
-                                prior_sd = 0.25,
+                                prior_sd = sqrt(1/12),
                                 iter = 25000,
                                 impute = TRUE,
                                 progress = TRUE,
-                                seed = 1){
+                                seed = NULL){
 
 
 
@@ -350,10 +350,11 @@ ggm_compare_confirm <- function(...,
                    "currently only implemented for 'continuous' data."))
   }
 
-  # removed per CRAN (8/12/21)
-  # old <- .Random.seed
-
   set.seed(seed)
+  ## Random seed unless user provided
+  if(!is.null(seed) ) {
+    set.seed(seed)
+  }
 
   # prior prob
   priorprob <- 1
