@@ -15,7 +15,7 @@
 #'
 #'
 #' @param prior_sd The scale of the prior distribution (centered at zero), in reference to a beta distribtuion
-#'                 (defaults to 0.50).
+#'                 (defaults to sqrt(1/12)).
 #'                 See note for further details.
 #'
 #' @param type Character string. Which type of data for \strong{Y} ? The options include \code{continuous},
@@ -147,23 +147,22 @@
 #' \donttest{
 #' # note: iter = 250 for demonstrative purposes
 #'
-#' # data
-#' Y <- bfi
+#' # data: Remove missings for "ordinal"
+#' Y <- bfi[complete.cases(bfi),]
 #'
 #' # males and females
 #' Ymale <- subset(Y, gender == 1,
 #'                    select = -c(gender,
 #'                                education))[,1:10]
-#'
+#' 
 #' Yfemale <- subset(Y, gender == 2,
 #'                      select = -c(gender,
 #'                                  education))[,1:10]
-#'
+#' 
 #' # fit model
 #' fit <- ggm_compare_estimate(Ymale,  Yfemale,
 #'                            type = "ordinal",
 #'                            iter = 250,
-#'                            prior_sd = 0.25,
 #'                            progress = FALSE)
 #'
 #' ###########################
@@ -195,7 +194,7 @@ ggm_compare_estimate <- function(...,
                                  type = "continuous",
                                  mixed_type = NULL,
                                  analytic = FALSE,
-                                 prior_sd = 0.50,
+                                 prior_sd = sqrt(1/12),
                                  iter = 5000,
                                  impute = TRUE,
                                  progress = TRUE,
@@ -393,9 +392,8 @@ ggm_compare_estimate <- function(...,
 #'
 #' # fit model
 #' fit <- ggm_compare_estimate(Ymale,  Yfemale,
-#'                             type = "ordinal",
+#'                             type = "continuous",
 #'                             iter = 250,
-#'                             prior_sd = 0.25,
 #'                             progress = FALSE)
 #'
 #' summary(fit)
@@ -591,16 +589,16 @@ print_summary_ggm_estimate_compare <- function(x,...){
 #' \donttest{
 #' # note: iter = 250 for demonstrative purposes
 #' # data
-#' Y <- bfi
+#' Y <- bfi[complete.cases(bfi),]
 #'
 #' # males and females
 #' Ymale <- subset(Y, gender == 1,
 #'                 select = -c(gender,
-#'                             education))[,1:5]
+#'                             education))[,1:10]
 #'
 #' Yfemale <- subset(Y, gender == 2,
 #'                   select = -c(gender,
-#'                               education))[,1:5]
+#'                               education))[,1:10]
 #'
 #' # fit model
 #' fit <- ggm_compare_estimate(Ymale,  Yfemale,
