@@ -12,7 +12,7 @@
 #'
 #' @param rho_sd Numeric. Scale of the prior distribution for the partial correlations,
 #' approximately the standard deviation of a beta distribution
-#' (defaults to 0.50).
+#' (defaults to sqrt(1/12) as this results to delta=2, and a uniform distribution across the partial correlations).
 #'
 #' @param beta_sd Numeric. Standard deviation of the prior distribution for the regression coefficients
 #'        (defaults to 1). The prior is by default centered at zero and follows a normal distribution
@@ -65,18 +65,29 @@
 #'
 #' }
 #' @export
-var_estimate <- function(Y, rho_sd = 0.50,
+var_estimate <- function(Y,
+                         rho_sd = sqrt(1/12),
                          beta_sd = 1,
                          iter = 5000,
                          progress = TRUE,
-                         seed = 1,
+                         seed = NULL,
                          ...) {
 
-  # removed per CRAN (8/12/21)
-  #old <- .Random.seed
-
   set.seed(seed)
+  ## Random seed unless user provided
+  if(!is.null(seed) ) {
+    set.seed(seed)
+  }
 
+  ## Check for constant values in variables:
+  if( sum(apply(Y, 2, FUN = function(x) sd(x, na.rm = TRUE)) == 0) > 0 ) {
+    pos <- which(apply(Y, 2, FUN = function(x) sd(x)) == 0)
+    insult <- names(Y)[pos]
+    stop(
+      cat("\nThe variable(s):",insult, "contain(s) only constant values. Please remove and re-run.\n\n")
+    )
+  }
+  
   Y <- scale(na.omit(Y))
   # number of nodes
   p <- ncol(Y)
